"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getHighlighter = getHighlighter;
exports.getSafeLanguage = getSafeLanguage;
exports.isValidLanguage = isValidLanguage;
var _core = require("@shikijs/core");
var _css = _interopRequireDefault(require("shiki/dist/langs/css.mjs"));
var _html = _interopRequireDefault(require("shiki/dist/langs/html.mjs"));
var _javascript = _interopRequireDefault(require("shiki/dist/langs/javascript.mjs"));
var _json = _interopRequireDefault(require("shiki/dist/langs/json.mjs"));
var _markdown = _interopRequireDefault(require("shiki/dist/langs/markdown.mjs"));
var _php = _interopRequireDefault(require("shiki/dist/langs/php.mjs"));
var _tsx = _interopRequireDefault(require("shiki/dist/langs/tsx.mjs"));
var _typescript = _interopRequireDefault(require("shiki/dist/langs/typescript.mjs"));
var _githubDark = _interopRequireDefault(require("shiki/dist/themes/github-dark.mjs"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/* eslint-disable no-console */

// Define raw languages with proper typing
const rawLanguages = {
  typescript: _typescript.default,
  javascript: _javascript.default,
  json: _json.default,
  html: _html.default,
  css: _css.default,
  markdown: _markdown.default,
  tsx: _tsx.default,
  php: _php.default,
  plaintext: {
    id: 'plaintext',
    scopeName: 'source.plaintext',
    patterns: [{
      match: '.*',
      name: 'text.plain'
    }],
    repository: {}
  }
};
const DEBUG = true;
function log(message, ...args) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
let highlighterInstance = null;

// Create a simple regex engine that doesn't rely on complex transformations
function createSimpleRegexEngine() {
  return {
    createScanner: patterns => ({
      findNextMatchSync: s => {
        for (let i = 0; i < patterns.length; i++) {
          try {
            if (patterns[i]) {
              const regex = new RegExp(patterns[i] || '', 'g');
              const match = regex.exec(s);
              if (match) {
                return {
                  index: match.index,
                  matches: match,
                  pattern: i,
                  captureIndices: match.map((m, idx) => ({
                    start: match.index,
                    end: match.index + m.length,
                    length: m.length,
                    index: idx
                  }))
                };
              }
            }
          } catch (e) {
            console.warn('Invalid regex pattern:', patterns[i], e);
          }
        }
        return null;
      }
    }),
    createString: s => ({
      content: s,
      toString: () => s
    })
  };
}

// Process raw languages into LanguageRegistrations
function processLanguages() {
  return Object.entries(rawLanguages).map(([key, rawLang]) => {
    const lang = Array.isArray(rawLang) ? rawLang[0] : rawLang;
    return {
      name: lang.name || key,
      scopeName: lang.scopeName || `source.${key}`,
      patterns: lang.patterns || [],
      repository: lang.repository || {},
      aliases: lang.aliases || [],
      embeddedLangs: lang.embeddedLanguages || []
    };
  });
}
async function getHighlighter() {
  if (highlighterInstance) {
    return highlighterInstance;
  }
  try {
    // Create highlighter with simple regex engine
    highlighterInstance = await (0, _core.createHighlighterCore)({
      themes: [(0, _core.normalizeTheme)(_githubDark.default)],
      langs: processLanguages(),
      engine: createSimpleRegexEngine()
    });
    return highlighterInstance;
  } catch (error) {
    console.error('Error creating highlighter:', error);
    throw error;
  }
}
function isValidLanguage(lang) {
  const normalized = lang.toLowerCase();
  return Object.keys(rawLanguages).includes(normalized);
}
function getSafeLanguage(lang) {
  const normalized = lang.toLowerCase();
  if (isValidLanguage(normalized)) {
    return normalized;
  }
  log(`Warning: Unsupported language '${lang}', falling back to plaintext`);
  return 'plaintext';
}
//# sourceMappingURL=SyntaxContext.js.map