"use strict";

/* eslint-disable no-console */

import { createHighlighterCore, normalizeTheme } from '@shikijs/core';
import css from 'shiki/dist/langs/css.mjs';
import html from 'shiki/dist/langs/html.mjs';
import javascript from 'shiki/dist/langs/javascript.mjs';
import json from 'shiki/dist/langs/json.mjs';
import markdown from 'shiki/dist/langs/markdown.mjs';
import php from 'shiki/dist/langs/php.mjs';
import tsx from 'shiki/dist/langs/tsx.mjs';
import typescript from 'shiki/dist/langs/typescript.mjs';
import githubDark from 'shiki/dist/themes/github-dark.mjs';

// Define raw languages with proper typing
const rawLanguages = {
  typescript,
  javascript,
  json,
  html,
  css,
  markdown,
  tsx,
  php,
  plaintext: {
    id: 'plaintext',
    scopeName: 'source.plaintext',
    patterns: [{
      match: '.*',
      name: 'text.plain'
    }],
    repository: {}
  }
};
const DEBUG = true;
function log(message, ...args) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
let highlighterInstance = null;

// Create a simple regex engine that doesn't rely on complex transformations
function createSimpleRegexEngine() {
  return {
    createScanner: patterns => ({
      findNextMatchSync: s => {
        for (let i = 0; i < patterns.length; i++) {
          try {
            if (patterns[i]) {
              const regex = new RegExp(patterns[i] || '', 'g');
              const match = regex.exec(s);
              if (match) {
                return {
                  index: match.index,
                  matches: match,
                  pattern: i,
                  captureIndices: match.map((m, idx) => ({
                    start: match.index,
                    end: match.index + m.length,
                    length: m.length,
                    index: idx
                  }))
                };
              }
            }
          } catch (e) {
            console.warn('Invalid regex pattern:', patterns[i], e);
          }
        }
        return null;
      }
    }),
    createString: s => ({
      content: s,
      toString: () => s
    })
  };
}

// Process raw languages into LanguageRegistrations
function processLanguages() {
  return Object.entries(rawLanguages).map(([key, rawLang]) => {
    const lang = Array.isArray(rawLang) ? rawLang[0] : rawLang;
    return {
      name: lang.name || key,
      scopeName: lang.scopeName || `source.${key}`,
      patterns: lang.patterns || [],
      repository: lang.repository || {},
      aliases: lang.aliases || [],
      embeddedLangs: lang.embeddedLanguages || []
    };
  });
}
export async function getHighlighter() {
  if (highlighterInstance) {
    return highlighterInstance;
  }
  try {
    // Create highlighter with simple regex engine
    highlighterInstance = await createHighlighterCore({
      themes: [normalizeTheme(githubDark)],
      langs: processLanguages(),
      engine: createSimpleRegexEngine()
    });
    return highlighterInstance;
  } catch (error) {
    console.error('Error creating highlighter:', error);
    throw error;
  }
}
export function isValidLanguage(lang) {
  const normalized = lang.toLowerCase();
  return Object.keys(rawLanguages).includes(normalized);
}
export function getSafeLanguage(lang) {
  const normalized = lang.toLowerCase();
  if (isValidLanguage(normalized)) {
    return normalized;
  }
  log(`Warning: Unsupported language '${lang}', falling back to plaintext`);
  return 'plaintext';
}
//# sourceMappingURL=SyntaxContext.js.map